#! /usr/bin/python
# Copyright (c) 2015 Cumulus Networks, Inc.  All rights reserved.

#############################################################################
# Platform and model specific eeprom subclass, inherits from the base class,
# and provides the followings:
# - the eeprom format definition
# - specific encoder/decoder if there is special need
#

try:
    import exceptions
    import binascii
    import time
    import optparse
    import warnings
    import os
    import sys
    import subprocess
    import tempfile
    import eeprom_base
    import eeprom_tlvinfo
except ImportError, e:
    raise ImportError (str(e) + "- required module not found")

#
# base board
#
class board(eeprom_tlvinfo.TlvInfoDecoder):

    EEPROM_MAX_SIZE = 0x800
    EEPROM_OFFSET = 0x0

    def __init__(self, name, path, cpld_root, ro):
        super(board, self).__init__(path,
                                    self.EEPROM_OFFSET,
                                    "",
                                    ro,
                                    self.EEPROM_MAX_SIZE)


#
# power supply unit
#

class psu(eeprom_base.eepromDecoder):

    # This format is bogus.  Find out what it is later.
    ps_fmt = [ ('burn',        'x', 12),    # offset 0
               ('manufacturer','s',  9),    # offset 21
               ('part_num',    's', 11),    # offset 32
               ('model_num',   's',  9),    # offset 41
               ('revision',    's',  5),    # offset 46
               ('serial_num',  's', 18),    # offset 64
               ]

    def __init__(self, name, path, cpld_root, ro):
        cpld_root = '/sys/bus/i2c/devices/0-0030'
        cpld_path = cpld_root + '/psu_pwr' + name.split('psu')[1] + '_all_ok'
        super(psu, self).__init__(path,         \
                                  self.ps_fmt,  \
                                  0,            \
                                  cpld_path,    \
                                  ro)

    def decoder(self, s, t):
        # not implemented
        return 0

    def check_status(self):
        status = super(psu, self).check_status()

        # each device may have a different status string, decide what
        # translates to 'ok' here.
        if status.startswith('1'):
            return 'ok'
        else:
            return 'not present'

    def is_checksum_valid(self, e):
        # not implemented
        return (True, 0)

