#!/bin/sh

#
# Copyright 2015,2019 Cumulus Networks, Inc.
# All rights reserved.
#

# Invoked by /etc/init.d/hw_init

# The purpose of this script is to create the sensors config file on the very
# first boot.
#
# It first checks for the existance of the /etc/sensors.d/accton_as4610_54.conf
# file.  If the file exists, then exit normally.  If the file doesn't exist,
# determine whether this is a POE enabled switch or not.  Depending of the
# result, create the appropriate configuration file.

SENSORS_CONF="/etc/sensors.d/accton_as4610_54.conf"
CPLD_SYSFS="/sys/bus/i2c/devices/0-0030"
POE_SUPPORT="${CPLD_SYSFS}/poe_support"
PRODUCT_ID="${CPLD_SYSFS}/product_id"


make_sensors_conf()
{
    poe_support=$1
    product_id=$2

    mkdir -p $(dirname ${SENSORS_CONF})

    cat <<EOF > ${SENSORS_CONF}
# libsensors configuration file for Accton AS4610-54
# ---------------------------------------------------
#

# Bus declarations.  These are requred when using names that
# are fully specified with no wild cards.
bus "i2c-0" "iproc-smb0"
bus "i2c-17" "i2c-1-mux (chan_id 7)"

chip "*-i2c-0-30"
EOF

    if [ "${poe_support}" = "0" -a "${product_id}" = "AS4610-48" ] ; then
	cat <<EOF >> ${SENSORS_CONF}
    # Non POE switches do not have a fan
    ignore fan1
EOF
    fi

    cat <<EOF >> ${SENSORS_CONF}

# Main board temperature sensor
chip "lm77-i2c-17-48"
    label temp1 "ambient temp"
    set temp1_crit 75
    set temp1_crit_hyst 70
    set temp1_max 60
    set temp1_min 10


EOF

}


# Main program starts here

# The configuration file only needs to be created once.  If it already
# exists, don't touch it.

[ -r ${SENSORS_CONF} ] || {

# Sanity check

    [ -d ${CPLD_SYSFS} ] || {
	log_failure_msg "Unable to find cpld: ${CPLD_SYSFS}"
	exit 1
    }

# Get poe_support

    [ -r ${POE_SUPPORT} ] || {
	log_failure_msg "Unable to find ${CPLD_SYSFS}: poe_support"
	exit 1
    }
    poe_support=$(cat ${POE_SUPPORT})

# Get product_id
    [ -r ${PRODUCT_ID} ] || {
	log_failure_msg "Unable to find ${CPLD_SYSFS}: product_id"
	exit 1
    }
    product_id=$(cat ${PRODUCT_ID})

# Create the sensors conf file

    make_sensors_conf ${poe_support} ${product_id}

}
