#!/bin/sh

#
# Copyright 2016 Cumulus Networks, Inc.
# All rights reserved.
#

# Invoked by /etc/init.d/hw_init

#
# 48 x SFP+ ports
# ===============
# - set TX_ENABLE to 1
#
# 6 x QSFP+ ports
# ===============
# - set LOW_POWER_MODE to 0 (use high power mode)
# - take out of reset

[ "$1" = "start" ] || exit 0

# Load the VERBOSE setting and other rcS variables
. /lib/init/vars.sh

# Define LSB log_* functions.
# Depend on lsb-base (>= 3.2-14) to ensure that this file is present
# and status_of_proc is working.
. /lib/lsb/init-functions

log_action_msg "  Initializing SFP+/QSFP+"

sysfs_cpld="/sys/devices/platform/accton_as5712_54x_cpld.0"

# Sanity checking:
for f in sfp_tx_enable qsfp_lp_mode qsfp_reset ; do
    [ -w "${sysfs_cpld}/$f" ] || {
        log_failure_msg "Unable to find writable SFP+/QSFP+ sysfs control: ${sysfs_cpld}/$f"
        exit 1
    }
done

# 48 x SFP+ ports
# ===============
# - set TX_ENABLE to 1
echo 0xFFFFFFFFFFFF > "${sysfs_cpld}/sfp_tx_enable"

# 6 x QSFP+ ports
# ===============
# - set LOW_POWER_MODE to 0 (use high power mode)
echo 0x0 > "${sysfs_cpld}/qsfp_lp_mode"


# - take QSFP+ modules out of reset
echo 0x0 > "${sysfs_cpld}/qsfp_reset"
