#!/bin/bash

#
# Copyright 2014 Cumulus Networks, Inc.
# All rights reserved.
#

# Invoked by /etc/init.d/hw_init

# Configure the GPIOs connected to the 4 QFSPs to:
# a) Take the module out of reset
# b) Enable the module

[ "$1" = "start" ] || exit 0

# Load the VERBOSE setting and other rcS variables
. /lib/init/vars.sh

# Define LSB log_* functions.
# Depend on lsb-base (>= 3.2-14) to ensure that this file is present
# and status_of_proc is working.
. /lib/lsb/init-functions

log_action_msg "  Initializing GPIOs.."

sysfs_gpio="/sys/class/gpio"
gpio_chips="144 184"
expected_label="pca9506"
expected_ngpio="40"

# Sanity checking:
for chip in $gpio_chips; do
    [ -d "$sysfs_gpio/gpiochip${chip}" ] || {
        log_failure_msg "Unable to find QSFP GPIO chip: gpiochip${chip}"
        exit 1
    }

    label="$(cat $sysfs_gpio/gpiochip${chip}/label)"
    [ "$label" = "$expected_label" ] || {
        log_failure_msg "Unexpected QSFP GPIO chip label: $label"
        exit 1
    }

    ngpio="$(cat $sysfs_gpio/gpiochip${chip}/ngpio)"
    [ "$ngpio" = "$expected_ngpio" ] || {
        log_failure_msg "Unexpected QSFP GPIO chip ngpio: $ngpio"
        exit 1
    }
done

set_gpio() {
    start=$1
    stop=$2
    value=$3

    for gpio in `seq $start $stop`; do
        echo $gpio > $sysfs_gpio/export

        gpio_path="$sysfs_gpio/gpio${gpio}"
        [ -d "$gpio_path" ] || {
            log_failure_msg "Unable to export GPIO: $gpio"
            exit 1
        }

        echo out > "$gpio_path/direction"
        echo $value > "$gpio_path/value"
    done
}

set_gpio_ro() {
    start=$1
    stop=$2

    for gpio in `seq $start $stop`; do
        echo $gpio > $sysfs_gpio/export

        gpio_path="$sysfs_gpio/gpio${gpio}"
        [ -d "$gpio_path" ] || {
            log_failure_msg "Unable to export GPIO: $gpio"
            exit 1
        }
    done
}

# 144 - 149: reset_l (output) for module 1 qsfp1..6
set_gpio 144 149 1
# 150 - 155: lpmod (output) for module 1 qsfp1..6
set_gpio 150 155 0
# 156 - 161: modsel_l (output) for module 1 qsfp1..6
set_gpio 156 161 0
# 162 - 167: present_l (input) for module 1 qsfp1..6
set_gpio_ro 162 167

# 184 - 189: reset_l (output) for module 1 qsfp1..6
set_gpio 184 189 1
# 190 - 195: lpmod (output) for module 1 qsfp1..6
set_gpio 190 195 0
# 196 - 201: modsel_l (output) for module 1 qsfp1..6
set_gpio 196 201 0
# 202 - 207: present_l (input) for module 1 qsfp1..6
set_gpio_ro 202 207

echo 0 > /sys/devices/soc.0/ffe03100.i2c/i2c-1/1-0031/qsfp_reset
sleep .1
echo 0xfffff > /sys/devices/soc.0/ffe03100.i2c/i2c-1/1-0031/qsfp_reset
