#!/bin/bash

. /lib/init/vars.sh
. /lib/lsb/init-functions

# register 0xff all channels
ALL_CHANNELS=0x0c
# register 0x1e DFE power down = 0 (power up dfe)
DEFAULT_DFE_POWER_DOWN=0xe1
# register 0x31 adaptation mode = 0x2 (CLTE + DFE)
DEFAULT_ADAPTATION_MODE=0x40
# register 0x36 ref_mode = 0 (No 25MHz reference clock)
DEFAULT_VEO_CLK_CDR_CAP=0x1
# register 0x0a CDR reset
CDR_RESET=0x1c
CDR_NORESET=0x10

DEM_TX_TABLE=(
0x00
0x12 0x12 0x12 0x12
0x12 0x12 0x12 0x12
0x12 0x12 0x12 0x12
0x12 0x12 0x12 0x12
0x12 0x12 0x12 0x12
0x52 0x12 0x52 0x12
0x52 0x12 0x53 0x12
0x53 0x12 0x53 0x12)

DEM_RX_TABLE=(
0x00
0x14 0x12 0x12 0x52
0x52 0x54 0x52 0x10
0x11 0x11 0x10 0x10
0x10 0x11 0x10 0x11
0x53 0x51 0x11 0x53
0x51 0x11 0x51 0x53
0x53 0x53 0x12 0x12
0x12 0x57 0x15 0x15)

VOD_TX_TABLE=(
0x00
0x83 0x83 0x83 0x83
0x83 0x83 0x83 0x83
0x83 0x83 0x83 0x83
0x83 0x83 0x83 0x83
0x83 0x83 0x83 0x83
0x81 0x83 0x81 0x83
0x81 0x83 0x81 0x83
0x81 0x83 0x81 0x83)

VOD_RX_TABLE=(
0x00
0x84 0x83 0x83 0x82
0x82 0x82 0x81 0x80
0x81 0x81 0x80 0x80
0x80 0x80 0x80 0x81
0x82 0x81 0x82 0x81
0x81 0x81 0x81 0x82
0x83 0x83 0x83 0x83
0x84 0x87 0x87 0x87)

set_retimer() {
    path=$1
    port=$2
    direction=$3

    echo $ALL_CHANNELS > $path/channels

    if [ $port -gt 19 ]; then
        echo $DEFAULT_DFE_POWER_DOWN > $path/pfd_prbs_dfe
        echo $DEFAULT_ADAPTATION_MODE > $path/adapt_eq_sm
    fi

    echo $DEFAULT_VEO_CLK_CDR_CAP > $path/veo_clk_cdr_cap

    echo $CDR_RESET > $path/cdr_rst
    echo $CDR_NORESET > $path/cdr_rst

    if [ $direction == 'rx' ]; then
        echo ${DEM_RX_TABLE[$port]} > $path/tap_dem
        echo ${VOD_RX_TABLE[$port]} > $path/drv_sel_vod
    else
        echo ${DEM_TX_TABLE[$port]} > $path/tap_dem
        echo ${VOD_TX_TABLE[$port]} > $path/drv_sel_vod
    fi
}

log_action_msg "  Initializing Retimers.."

rdir="/sys/class/retimer_dev"

# Sanity Checking
[ -d $rdir ] || {
    log_failure_msg "Unable to find retimer class dir: $rdir"
    exit 1
}

for retimer in $rdir/retimer*; do
    label=`cat $retimer/label`
    retimer_path="$retimer/device"
    retimer=${label:4}
    retimer_port=${retimer%%_?x}
    retimer_direction=${retimer:(-2)}

    set_retimer $retimer_path $retimer_port $retimer_direction
done
