#!/bin/sh

#
# Copyright 2015 Cumulus Networks, Inc.
# All rights reserved.
#

# Invoked by /etc/init.d/hw_init

# Configure the GPIOs connected to the optical modules
#
# 32 x QSFP+ ports
# ===============
# - set LOW_POWER_MODE to 0 (use high power mode)
# - take out of reset

[ "$1" = "start" ] || exit 0

# Load the VERBOSE setting and other rcS variables
. /lib/init/vars.sh

# Define LSB log_* functions.
# Depend on lsb-base (>= 3.2-14) to ensure that this file is present
# and status_of_proc is working.
. /lib/lsb/init-functions

log_action_msg "  Initializing QSFP+ GPIOs..."

sysfs_cpld="/sys/devices/platform/accton_as6712_32x_cpld.0"

# Sanity checking:
for f in qsfp_lp_mode qsfp_reset ; do
    [ -w "${sysfs_cpld}/$f" ] || {
        log_failure_msg "Unable to find writable SFP+/QSFP+ sysfs control: ${sysfs_cpld}/$f"
        exit 1
    }
done


# 32 x QSFP+ ports
# ===============
# - set LOW_POWER_MODE to 0 (use high power mode)
echo 0x0 > "${sysfs_cpld}/qsfp_lp_mode"


# - take QSFP+ modules out of reset
echo 0x0 > "${sysfs_cpld}/qsfp_reset"
