#! /usr/bin/python
# Copyright 2016 Cumulus Networks, Inc.
# All rights reserved

#############################################################################
# Platform and model specific eeprom subclass, inherits from the base class,
# and provides the followings:
# - the eeprom format definition
# - specific encoder/decoder if there is special need
#

try:
    import exceptions
    import binascii
    import time
    import optparse
    import warnings
    import os
    import sys
    import subprocess
    import tempfile
    import struct
    import eeprom_base
    import eeprom_tlvinfo
    import eeprom_ipmi_fru
    import syslog
except ImportError, e:
    raise ImportError (str(e) + "- required module not found")

#
# base board
#
class board(eeprom_tlvinfo.TlvInfoDecoder):

    EEPROM_MAX_SIZE = 0x100
    EEPROM_OFFSET = 0x0

    def __init__(self, name, path, cpld_root, ro):
        super(board, self).__init__(path,
                                    self.EEPROM_OFFSET,
                                    "",
                                    ro,
                                    self.EEPROM_MAX_SIZE)
#
# power supply unit
#
class psu(eeprom_ipmi_fru.IpmiFruDecoder):

    def check_status(self):
        path = '/sys/devices/platform/accton_as6712_32x_cpld.0/psu_pwr' \
            + self.name.split('psu')[1] + '_all_ok'

        try:
            with open(path, "r") as fp:
                status = fp.readline().rstrip()
            if int(status):
                return 'ok'
            return 'absent'
        except:
            return 'absent'

def determine_eeprom_sysfs_map():
    #
    # To support a new PSU type on this platform, just append its PSU1
    # and PSU2 I2C paths in a new entry to the psu_paths[] list.
    #
    psu_paths = [
                  [ '/sys/bus/i2c/devices/11-0038/eeprom',    # CPR
                    '/sys/bus/i2c/devices/12-003b/eeprom'
                  ],
                  [ '/sys/bus/i2c/devices/11-0050/eeprom',    # 3Y
                    '/sys/bus/i2c/devices/12-0053/eeprom'
                  ]
                ]

    sysfs_map = {}
    for i in range(len(psu_paths)):
        for j in range(len(psu_paths[i])):
            path = psu_paths[i][j]

            #
            # Iff a test read succeeds, add psu entry to sysfs_map{}.
            # This allows any mix of PSUs with platform module support
            # to be installed in the switch and detected here by smond.
            #
            try:
                with open(path, "r") as fp:
                    line = fp.read(1)
            except IOError as err:
                syslog.syslog(syslog.LOG_INFO, "Unable to find eeprom at %s for psu%d" % (path, i + 1))
                pass
            else:
                k = 'psu' + str(j+1)
                v = ['psu', path]
                sysfs_map[k] = v

    return sysfs_map

eeprom_sysfs_map = {}
eeprom_sysfs_map.update(determine_eeprom_sysfs_map())
