#! /usr/bin/python
# Copyright 2018, 2020 Cumulus Networks, Inc.
# All rights reserved

#############################################################################
# Platform and model specific eeprom subclass, inherits from the base class,
# and provides the followings:
# - the eeprom format definition
# - specific encoder/decoder if there is special need
#

try:
    import eeprom_base
    import eeprom_tlvinfo
    import eeprom_ipmi_fru
except ImportError, e:
    raise ImportError (str(e) + "- required module not found")

#
# base board
#
class board(eeprom_tlvinfo.TlvInfoDecoder):

    EEPROM_MAX_SIZE = 0x100
    EEPROM_OFFSET = 0x0

    def __init__(self, name, path, cpld_root, ro):
        super(board, self).__init__(path,
                                    self.EEPROM_OFFSET,
                                    "",
                                    ro,
                                    self.EEPROM_MAX_SIZE)

    def switchaddrstr(self, e):
        return self.add_mac(self.base_mac_addr(e), 3)

#
# power supply unit
#
class psu(eeprom_ipmi_fru.IpmiFruDecoder):

    def check_status(self):
        path = '/sys/devices/platform/accton_as7326_56x_cpld.0/psu_pwr' \
            + self.name.split('psu')[1]

        try:
            with open(path, "r") as fp:
                status = fp.readline().rstrip()
            if status.find('ok') >= 0:
                return 'ok'
            return 'absent'
        except:
            return 'absent'
