#! /usr/bin/python
# Copyright 2016 Cumulus Networks, Inc.
# All rights reserved

#############################################################################
# Platform and model specific eeprom subclass, inherits from the base class,
# and provides the followings:
# - the eeprom format definition
# - specific encoder/decoder if there is special need
#

try:
    import exceptions
    import binascii
    import time
    import optparse
    import warnings
    import os
    import sys
    import subprocess
    import tempfile
    import struct
    import eeprom_base
    import eeprom_tlvinfo
    import eeprom_ipmi_fru
except ImportError, e:
    raise ImportError (str(e) + "- required module not found")

#
# base board
#
class board(eeprom_tlvinfo.TlvInfoDecoder):

    EEPROM_MAX_SIZE = 0x100
    EEPROM_OFFSET = 0x0

    def __init__(self, name, path, cpld_root, ro):
        super(board, self).__init__(path,
                                    self.EEPROM_OFFSET,
                                    "",
                                    ro,
                                    self.EEPROM_MAX_SIZE)
#
# power supply unit
#
class psu(eeprom_ipmi_fru.IpmiFruDecoder):

    def check_status(self):
        path = '/sys/devices/platform/accton_as7712_32x_cpld.0/psu_pwr' \
            + self.name.split('psu')[1]

        try:
            with open(path, "r") as fp:
                status = fp.readline().rstrip()
            if status.find('ok') >= 0:
                return 'ok'
            return 'absent'
        except:
            return 'absent'

class fan(eeprom_base.eepromDecoder):

    def __init__(self, name, path, cpld_root, ro):
        # Not even sure the fans have EEPROMs....
        raise NotImplementedError

class spd(eeprom_base.eepromDecoder):

    def __init__(self, name, path, cpld_root, ro):
        # This all belongs in a common class...
        raise NotImplementedError
