#! /usr/bin/python
# Copyright 2015 Cumulus Networks, Inc.
# All rights reserved

#############################################################################
# Platform and model specific eeprom subclass, inherits from the base class,
# and provides the followings:
# - the eeprom format definition
# - specific encoder/decoder if there is special need
#

try:
    import exceptions
    import binascii
    import time
    import optparse
    import warnings
    import os
    import sys
    import subprocess
    import tempfile
    import struct
    import eeprom_tlvinfo
    import eeprom_base
except ImportError, e:
    raise ImportError (str(e) + "- required module not found")

#
# base board
#
class board(eeprom_tlvinfo.TlvInfoDecoder):

    EEPROM_MAX_SIZE = 0x100
    EEPROM_OFFSET = 0x0

    def __init__(self, name, path, cpld_root, ro):
        super(board, self).__init__(path,
                                    self.EEPROM_OFFSET,
                                    "",
                                    ro,
                                    self.EEPROM_MAX_SIZE)


class fan(eeprom_tlvinfo.TlvInfoDecoder):
    EEPROM_MAX_SIZE = 0x100
    EEPROM_OFFSET = 0x0

    def __init__(self, name, path, cpld_root, ro):
        super(fan, self).__init__(path,
                                    self.EEPROM_OFFSET,
                                    "",
                                    ro,
                                    self.EEPROM_MAX_SIZE)
        
class psu(eeprom_base.eepromDecoder):
    ps_fmt = [ ('burn', 'x', 32),
               ('description',       's', 16),
               ('serial_num',        's', 32),
               ('mfg_part_num',      's', 16),
               ('customer_part_num', 's', 16),
    ]

    def __init__(self, name, path, cpld_root, ro):
        cpld_path = '/sys/devices/platform/cel_e1031_cpld.0/psu_pwr' + name.split('psu')[1] + '_ac'
        super(psu, self).__init__(path, self.ps_fmt, 0, cpld_path, ro)

    def check_status(self):
        status = super(psu, self).check_status()
        # each device may have a different status string, decide what
        # translates to 'ok' here.
        if status.startswith('ok'):
            return 'ok'
        else:
            return status

    def is_checksum_valid(self, e):
        # not there
        return (True, 0)
