#! /usr/bin/python
# Copyright 2012 Cumulus Networks LLC, all rights reserved

#############################################################################
# Platform and model specific eeprom subclass, inherits from the base class,
# and provides the followings:
# - the eeprom format definition
# - specific encoder/decoder if there is special need
#

try:
    import exceptions
    import binascii
    import time
    import optparse
    import warnings
    import os
    import sys
    import subprocess
    import tempfile
    import eeprom_base
    import eeprom_tlvinfo
    import eeprom_ipmi_fru
except ImportError, e:
    raise ImportError (str(e) + "- required module not found")

# Current TLV based EEPROM format
class board_tlv_format(eeprom_tlvinfo.TlvInfoDecoder):

    EEPROM_MAX_SIZE = 0x2000

    def __init__(self, name, path, cpld_root, ro):
        super(board_tlv_format, self).__init__(path, 0, "", ro, self.EEPROM_MAX_SIZE)

def board(name, path, cpld_root, ro):
    return board_tlv_format(name, path, cpld_root, ro)

#
# power supply unit
#
class psu(eeprom_ipmi_fru.IpmiFruDecoder):

    def check_status(self):
        path = '/sys/class/gpio/psu_pwr' + self.name.split('psu')[1] + \
            '_present/value'
        try:
            with open(path, "r") as fp:
                status = fp.readline().rstrip()
            if int(status):
                return 'ok'
            return 'absent'
        except:
            return 'absent'
