#!/bin/sh

#
# Copyright 2016 Cumulus Networks, Inc.
# All rights reserved.
#

# Invoked by /etc/init.d/hw_init

# Populate the Board EEPROM for Cumulus VX on every install

# Load the VERBOSE setting and other rcS variables
. /lib/init/vars.sh

# Define LSB log_* functions.
# Depend on lsb-base (>= 3.2-14) to ensure that this file is present
# and status_of_proc is working.
. /lib/lsb/init-functions

log_action_msg "Updating Board EEPROM"

err=0
/usr/cumulus/bin/decode-syseeprom -s 0x2d="Cumulus Networks" > /dev/null || {
    log_failure_msg "Problem updating Vendor Name in Board EEPROM"
    err=1
}
/usr/cumulus/bin/decode-syseeprom -s 0x21="VX" > /dev/null || {
    log_failure_msg "Problem updating Product Name in Board EEPROM"
    err=1
}
/usr/cumulus/bin/decode-syseeprom -s 0x26="3" > /dev/null || {
    log_failure_msg "Problem updating Device Version in Board EEPROM"
    err=1
}
part_num=`cat /etc/image-release  | grep IMAGE_RELEASE | awk -F '=' '{print $2}'`
/usr/cumulus/bin/decode-syseeprom -s 0x22=$part_num > /dev/null || {
    log_failure_msg "Problem updating Part Number in Board EEPROM"
    err=1
}

num=`ip link show | grep -c "swp[0-9]\|eth[0-9]"`
if [ $num -gt 0 ]; then
    /usr/cumulus/bin/decode-syseeprom -s 0x2a=$num > /dev/null || {
	log_failure_msg "Problem updating No of MAC Addresses in Board EEPROM"
	err=1
    }
    mac=`ip link show eth0 | grep link | awk '{print $2}'`
    /usr/cumulus/bin/decode-syseeprom -s 0x24=$mac > /dev/null || {
	log_failure_msg "Problem updating Base MAC Address in Board EEPROM"
	err=1
    }
    /usr/cumulus/bin/decode-syseeprom -s 0x23=$mac > /dev/null || {
	log_failure_msg "Problem updating Serial Number in Board EEPROM"
	err=1
    }
fi

# Make EEPROM read-only, as it should be on real hardware.
chmod 444 /sys/class/eeprom_dev/eeprom0/device/eeprom

if [ $err = "1" ] ; then
    exit 1
fi
