#! /usr/bin/python
# Copyright 2015 Cumulus Networks, Inc.
# All rights reserved

#############################################################################
# Platform and model specific eeprom subclass, inherits from the base class,
# and provides the followings:
# - the eeprom format definition
# - specific encoder/decoder if there is special need
#

try:
    import exceptions
    import binascii
    import time
    import optparse
    import warnings
    import os
    import sys
    import subprocess
    import tempfile
    import struct
    import eeprom_base
    import eeprom_tlvinfo
    import eeprom_sysfs
except ImportError, e:
    raise ImportError (str(e) + "- required module not found")

#
# base board
#
class board(eeprom_tlvinfo.TlvInfoDecoder):

    EEPROM_MAX_SIZE = 0x100
    EEPROM_OFFSET = 0x0

    def __init__(self, name, path, cpld_root, ro):
        super(board, self).__init__(path,
                                    self.EEPROM_OFFSET,
                                    "",
                                    ro,
                                    self.EEPROM_MAX_SIZE)

class psu(eeprom_sysfs.SysFsDecoder):
    pass

class fan(eeprom_sysfs.SysFsDecoder):
    pass

eeprom_path = '/sys/devices/platform/dell_z9100_smf.0/hwmon/'
if os.path.exists(eeprom_path):
    eeprom_path = os.path.join(eeprom_path, [f for f in os.listdir(eeprom_path) if f.startswith('hwmon')][0])

eeprom_sysfs_map = {
   # name   : [class_name, path] 
    'psu1'  : ['psu', eeprom_path],
    'psu2'  : ['psu', eeprom_path],
    'fan1'  : ['fan', eeprom_path],
    'fan2'  : ['fan', eeprom_path],
    'fan3'  : ['fan', eeprom_path],
    'fan4'  : ['fan', eeprom_path],
    'fan5'  : ['fan', eeprom_path],
    'fan6'  : ['fan', eeprom_path],
    'fan7'  : ['fan', eeprom_path],
    'fan8'  : ['fan', eeprom_path],
    'fan9'  : ['fan', eeprom_path],
    'fan10' : ['fan', eeprom_path],
}
        
