#!/bin/sh

#
# Copyright 2015,2016,2018 Cumulus Networks, Inc.  All rights reserved
# All rights reserved.
#

# Invoked by /etc/init.d/hw_init

# Determine the fan configuration for multiple Dell Z9100 SKUs and
# setup the fan related configuration files accordingly.

# The fan configuration files need only be setup once after a fresh
# install.

# Cache previously detected fan configuration
CACHE_DIR=/run/cache/cumulus/fan_config
CACHE_CONF="$CACHE_DIR/state"

SENSORS_CONF=/etc/sensors.d/dell_z9100_c2538.conf

# Load the VERBOSE setting and other rcS variables
. /lib/init/vars.sh

# Define LSB log_* functions.
# Depend on lsb-base (>= 3.2-14) to ensure that this file is present
# and status_of_proc is working.
. /lib/lsb/init-functions

detect_fans()
{
    # b2f_part_nums = ['09N7MF', '0GTX3X', '0KF3Y8', '0J86XN']
    # f2b_part_nums = ['04HXVK', '03GT5N', '0Y72TP', '062YMV']
    part_num=$(decode-syseeprom |grep 'Part Number'|awk '{print $5}')
    case "$part_num" in
    04HXVK|03GT5N|0Y72TP|062YMV)
        # F2B part nums
        FAN_CONFIG="F2B"
        ;;
    09N7MF|0GTX3X|0KF3Y8|0J86XN)
        # B2F part nums
        FAN_CONFIG="B2F"
        ;;
    *)
        # Default to B2F
        FAN_CONFIG="B2F"
        ;;
    esac
    # Store result in the cache
    mkdir -p $CACHE_DIR || {
        log_failure_msg "Problems making cache dir: $CACHE_DIR"
    }
    echo $FAN_CONFIG > $CACHE_CONF || {
        log_failure_msg "Problems writing cache file: $CACHE_CONF"
    }
}

# make_sensors_conf() -- Based on the fan type generate an appropriate
# sensors configuration file.
make_sensors_conf()
{
    config=$1

    # Emit common sensors config file text
    mkdir -p $(dirname $SENSORS_CONF)

    if [ $config = "F2B" ] ; then
        # Use front-to-back configuration
	cat <<EOF > $SENSORS_CONF
# libsensors configuration file for DELL Z9100 F2B
# ------------------------------------------------
#
# WARNING: Please do not edit this file, unless you know what you are doing.
# Intel CPU die Temp sensor
# sensor parameters are read-only.
chip "coretemp-isa-0000"

# DIMM Temp Sensors
chip "jc42-*"
     set temp1_crit 95
     set temp1_max 90
     set temp1_min 5

chip "dell_z9100_smf-isa-0000"
# Dell Z9100 has sensors controlled by a SmartFusion Controller
# The thresholds on these cannot be changed.
# temp1: U2900 - CPU On- board sensor
# temp2: U44 - Temp Sensor close to Networking ASIC
# temp3: U4 Front Panel (Left) Temp Sensor
# temp4: U2 - Front Panel (Right) Temp Sensor
# temp6: U38 - Temp Sensor close to Networking ASIC
# temp9: U2900 - Rear Temp Sensor
# temp11: PSU1 Temp
# temp12: PSU2 Temp
# fan1-fan10: system fans
# fan11: PSU1 Fan
# fan12: PSU2 Fan
     ignore temp5
     ignore temp6
     ignore temp7
     ignore temp8
     ignore temp9
EOF
    else
        # Use back-to-front configuration
	cat <<EOF > $SENSORS_CONF
# libsensors configuration file for DELL Z9100 B2F
# ------------------------------------------------
#
# WARNING: Please do not edit this file, unless you know what you are doing.
# Intel CPU die Temp sensor
# sensor parameters are read-only.
chip "coretemp-isa-0000"

# DIMM Temp Sensors
chip "jc42-*"
     set temp1_crit 95
     set temp1_max 90
     set temp1_min 5

chip "dell_z9100_smf-isa-0000"
# Dell Z9100 has sensors controlled by a SmartFusion Controller
# The thresholds on these cannot be changed.
# temp1: U2900 - CPU On- board sensor
# temp2: U44 - Temp Sensor close to Networking ASIC
# temp3: U4 Front Panel (Left) Temp Sensor
# temp4: U2 - Front Panel (Right) Temp Sensor
# temp6: U38 - Temp Sensor close to Networking ASIC
# temp9: U2900 - Rear Temp Sensor
# temp11: PSU1 Temp
# temp12: PSU2 Temp
# fan1-fan10: system fans
# fan11: PSU1 Fan
# fan12: PSU2 Fan
     ignore temp2
     ignore temp5
     ignore temp7
     ignore temp8

EOF
    fi
}

# Main program starts here

if [ -r $CACHE_CONF ] ; then
    FAN_CONFIG=$(cat $CACHE_CONF)
    if [ $FAN_CONFIG != "F2B" ] && [ $FAN_CONFIG != "B2F" ] ; then
        log_failure_msg "Unexpected fan config: $FAN_CONFIG"
        exit 1
    fi
else
    detect_fans
    make_sensors_conf $FAN_CONFIG
fi
