#! /usr/bin/python

# Copyright (c) 2019 Cumulus Networks, Inc.  All rights reserved

#############################################################################
# Platform and model specific eeprom subclass, inherits from the base class,
# and provides the followings:
# - the eeprom format definition
# - specific encoder/decoder if there is special need
#

try:
    import exceptions
    import binascii
    import time
    import optparse
    import warnings
    import os
    import sys
    import subprocess
    import tempfile
    import struct
    import eeprom_base
    import eeprom_tlvinfo
except ImportError, e:
    raise ImportError (str(e) + "- required module not found")


# board EEPROM

class board(eeprom_tlvinfo.TlvInfoDecoder):
    EEPROM_MAX_SIZE = 0x100
    EEPROM_OFFSET = 0x0

    def __init__(self, name, path, cpld_root, ro):
        super(board, self).__init__(path,
                                    self.EEPROM_OFFSET,
                                    "",
                                    ro,
                                    self.EEPROM_MAX_SIZE)

# fan EEPROMs

class fan(eeprom_tlvinfo.TlvInfoDecoder):
    EEPROM_MAX_SIZE = 0x100
    EEPROM_OFFSET = 0x0

    def __init__(self, name, path, cpld_root, ro):
        self.name = name
        super(fan, self).__init__(path,
                                    self.EEPROM_OFFSET,
                                    "",
                                    ro,
                                    self.EEPROM_MAX_SIZE)

# PSU EEPROMs

class psu(eeprom_base.eepromDecoder):

    ps_fmt = [ ('burn',              's', 196),
               ('Serial Number',     's', 20),
               ('Part Number',       's', 6),
               ('Label Revision',    's', 3),
               ('Airflow Direction', 's', 7),
               ('Power Source',      's', 5),
               ('Power (Wattage)',   's', 4),
               ('Number of Fans',    's', 1),
               ('Fan Speed',         's', 5),
               ('Checksum',          'c', 1)
             ]

    def __init__(self, name, path, cpld_root, ro):
        cpld_root = '/sys/devices/pci0000:00/0000:00:12.0/i2c-1/1-0032'
        cpld_path = cpld_root + '/psu_pwr' + name.split('psu')[1] + '_present'
        super(psu, self).__init__(path,         \
                                  self.ps_fmt,  \
                                  0,            \
                                  cpld_path,    \
                                  ro)

    def decoder(self, s, t):
        if s == 'checksum':
            i = "0x" + binascii.b2a_hex(t).upper()
        else:
            i = t
        return i

    def check_status(self):
        status = super(psu, self).check_status()

        # each device may have a different status string, decide what
        # translates to 'ok' here.
        if status.startswith('1'):
            return 'ok'
        else:
            return 'not present'

    def is_checksum_field(self, I):
        return I[0] == 'checksum'

    def checksum_field_size(self):
        return 1

    def checksum_type(self):
        return '2s-complement'

