#! /usr/bin/python

# Copyright (c) 2017 Cumulus Networks, Inc.  All rights reserved

#############################################################################
# Platform and model specific eeprom subclass, inherits from the base class,
# and provides the followings:
# - the eeprom format definition
# - specific encoder/decoder if there is special need
#

try:
    import exceptions
    import binascii
    import time
    import optparse
    import warnings
    import os
    import sys
    import subprocess
    import tempfile
    import struct
    import eeprom_base
    import eeprom_tlvinfo
except ImportError, e:
    raise ImportError (str(e) + "- required module not found")

#
# base board
#
class board(eeprom_tlvinfo.TlvInfoDecoder):
    EEPROM_MAX_SIZE = 0x100
    EEPROM_OFFSET = 0x0

    def __init__(self, name, path, cpld_root, ro):
        super(board, self).__init__(path,
                                    self.EEPROM_OFFSET,
                                    "",
                                    ro,
                                    self.EEPROM_MAX_SIZE)


class fan(eeprom_tlvinfo.TlvInfoDecoder):
    EEPROM_MAX_SIZE = 0x100
    EEPROM_OFFSET = 0x0

    def __init__(self, name, path, cpld_root, ro):
        self.name = name
        super(fan, self).__init__(path,
                                    self.EEPROM_OFFSET,
                                    "",
                                    ro,
                                    self.EEPROM_MAX_SIZE)

    def check_status(self):
        path = '/sys/bus/platform/devices/dellemc_s4148t_cpld.0/fan_' + self.name.split('fan')[1]
        try:
            with open(path, "r") as fp:
                status = fp.readline().rstrip()
            if status.find('ok') >= 0:
                return 'ok'
            return 'absent'
        except:
            return 'absent'

class psu(eeprom_base.eepromDecoder):
    EEPROM_OFFSET = 0xC4

    psu_format = [ ('serial_num',     's', 20),
                   ('mfg_part_num',   's',  6),
                   ('label_revision', 's',  3),
                   ('psu_direction',  's',  7),
                   ('psu_type',       's',  5),
                   ('power',          's',  4),
                   ('num_fans',       's',  1),
                   ('fan_speed',      's',  5),
                   ]

    def __init__(self, name, path, cpld_root, ro):
        cpld_path = '/sys/devices/platform/dellemc_s4148t_cpld.0/psu_pwr' + name.split('psu')[1]
        super(psu, self).__init__(path, self.psu_format, self.EEPROM_OFFSET, cpld_path, ro)
        self.name = name

    def check_status(self):
        path = '/sys/bus/platform/devices/dellemc_s4148t_cpld.0/psu_pwr' + self.name.split('psu')[1]

        try:
            with open(path, "r") as fp:
                status = fp.readline().rstrip()
                if status.find('ok') >= 0:
                    return 'ok'
                return 'absent'
        except:
            return 'absent'

    def is_checksum_valid(self, e):
        # not implemented
        return (True, 0)
