#!/bin/sh

#
# Copyright (c) 2017,2018 Cumulus Networks, Inc.  All rights reserved.
#

# Invoked by /etc/init.d/hw_init

# Determine the fan configuration for multiple Dell S4148T SKUs and
# setup the fan related configuration files accordingly.

# The fan configuration files need only be setup once after a fresh
# install.

# Cache previously detected fan configuration
CACHE_DIR=/run/cache/cumulus/fan_config
CACHE_CONF="$CACHE_DIR/state"

SENSORS_CONF=/etc/sensors.d/dell_s4148t_c2338.conf

# Load the VERBOSE setting and other rcS variables
. /lib/init/vars.sh

# Define LSB log_* functions.
# Depend on lsb-base (>= 3.2-14) to ensure that this file is present
# and status_of_proc is working.
. /lib/lsb/init-functions

detect_fans()
{
    #f2b_part_nums = ['04NM9P']
    #b2f_part_nums = ['0DNHJ0']

    part_num=$(decode-syseeprom |grep 'Part Number'|awk '{print $5}')
    case "$part_num" in
    04NM9P)
        # F2B part nums
        FAN_CONFIG="F2B"
        ;;
    0DNHJ0)
        # B2F part nums
        FAN_CONFIG="B2F"
        ;;
    *)
        # Default to B2F
        FAN_CONFIG="B2F"
        ;;
    esac
    # Store result in the cache
    mkdir -p $CACHE_DIR || {
        log_failure_msg "Problems making cache dir: $CACHE_DIR"
    }
    echo $FAN_CONFIG > $CACHE_CONF || {
        log_failure_msg "Problems writing cache file: $CACHE_CONF"
    }
}

# make_sensors_conf() -- Based on the fan type generate an appropriate
# sensors configuration file.
make_sensors_conf()
{
    config=$1

    # Emit common sensors config file text
    mkdir -p $(dirname $SENSORS_CONF)

    if [ $config = "F2B" ] ; then
        # Use front-to-back configuration
	cat <<EOF > $SENSORS_CONF
# libsensors configuration file for DELL S4148T C2338 F2B
# -------------------------------------------------------
#
# WARNING: Please do not edit this file, unless you know what you are doing.
#
# On Dell S4148T, the U278, U245, U244, U254, U288, U81, and U57 sensors
# control thermal hardware shutdown.  For these sesnors, when the temperature
# hits the temp1_max value, the box will undergo thermal hardware shutdown.
# The box will power up  once the temperature lowers to temp1_max_hyst.

bus "i2c-0" "SMBus I801 adapter at f000"
bus "i2c-1" "SMBus iSMT adapter at dff14000"
bus "i2c-10" "i2c-1-mux (chan_id 0)"
bus "i2c-11" "i2c-1-mux (chan_id 1)"
bus "i2c-12" "i2c-1-mux (chan_id 2)"
bus "i2c-13" "i2c-1-mux (chan_id 3)"
bus "i2c-14" "i2c-1-mux (chan_id 4)"
bus "i2c-15" "i2c-1-mux (chan_id 5)"
bus "i2c-16" "i2c-1-mux (chan_id 6)"
bus "i2c-17" "i2c-1-mux (chan_id 7)"

# Intel CPU die Temp sensor
# sensor parameters are read-only.
chip "coretemp-*"

# U278: tmp75-i2c-13-4b: Board sensor near Maverick
chip "tmp75-i2c-13-4b"
     label temp1 "board sensor near switch chip"
     set temp1_max 85
     set temp1_max_hyst 75

# U245: tmp75-i2c-13-4e: Board sensor near left of front vents
chip "tmp75-i2c-13-4e"
     label temp1 "board sensor near left of front vents"
     set temp1_max 80
     set temp1_max_hyst 70

# U244: tmp75-i2c-13-4a: Board sensor close to right PHY
chip "tmp75-i2c-13-4a"
     label temp1 "board sensor near right PHY"
     set temp1_max 86
     set temp1_max_hyst 76

# U254: tmp75-i2c-13-4c: Board sensor close to left PHY
chip "tmp75-i2c-13-4c"
     label temp1 "board sensor near left PHY"
     set temp1_max 88
     set temp1_max_hyst 78

# U288: tmp75-i2c-13-49: Board sensor between Maverick and QSFP
chip "tmp75-i2c-13-49"
     label temp1 "board sensor between switch chip and QSFP"
     set temp1_max 85
     set temp1_max_hyst 75

# U81: tmp75-i2c-13-4f: Board sensor close to fan
chip "tmp75-i2c-13-4f"
     label temp1 "board sensor near fan trays"
     set temp1_max 62
     set temp1_max_hyst 52

# U57: tmp75-i2c-10-4d: Board sensor near CPU
chip "tmp75-i2c-10-4d"
     label temp1 "board sensor near CPU"
     set temp1_max 65
     set temp1_max_hyst 55

# PSU1 and PSU2: 2 temp sensors and a fan sensor
chip "dps460-i2c-14-58"
     label fan1 "psu1 fan"
     label temp1 "psu1 inlet temp"
     label temp2 "psu1 heatsink temp"
     set temp1_max 65
     set temp2_max 65

chip "dps460-i2c-14-59"
     label fan1 "psu1 fan"
     label temp1 "psu1 inlet temp"
     label temp2 "psu1 heatsink temp"
     set temp1_max 65
     set temp2_max 65

# Fan sensors
chip "emc2305-i2c-11-4d"
     ignore fan5

chip "emc2305-i2c-13-4d"
     ignore fan5

# DIMM Temp Sensor
chip "jc42-i2c-0-1a"
     ignore temp1

EOF
    else
        # Use back-to-front configuration
	cat <<EOF > $SENSORS_CONF
# libsensors configuration file for DELL S4148T C2338 F2B
# -------------------------------------------------------
#
# WARNING: Please do not edit this file, unless you know what you are doing.
#
# On Dell S4148T, the U278, U245, U244, U254, U288, U81, and U57 sensors
# control thermal hardware shutdown.  For these sesnors, when the temperature
# hits the temp1_max value, the box will undergo thermal hardware shutdown.
# The box will power up  once the temperature lowers to temp1_max_hyst.

bus "i2c-0" "SMBus I801 adapter at f000"
bus "i2c-1" "SMBus iSMT adapter at dff14000"
bus "i2c-10" "i2c-1-mux (chan_id 0)"
bus "i2c-11" "i2c-1-mux (chan_id 1)"
bus "i2c-12" "i2c-1-mux (chan_id 2)"
bus "i2c-13" "i2c-1-mux (chan_id 3)"
bus "i2c-14" "i2c-1-mux (chan_id 4)"
bus "i2c-15" "i2c-1-mux (chan_id 5)"
bus "i2c-16" "i2c-1-mux (chan_id 6)"
bus "i2c-17" "i2c-1-mux (chan_id 7)"

# Intel CPU die Temp sensor
# sensor parameters are read-only.
chip "coretemp-*"

# U278: tmp75-i2c-13-4b: Board sensor near Maverick
chip "tmp75-i2c-13-4b"
     label temp1 "board sensor near switch chip"
     set temp1_max 82
     set temp1_max_hyst 72

# U245: tmp75-i2c-13-4e: Board sensor near left of front vents
chip "tmp75-i2c-13-4e"
     label temp1 "board sensor near left of front vents"
     set temp1_max 87
     set temp1_max_hyst 77

# U244: tmp75-i2c-13-4a: Board sensor close to right PHY
chip "tmp75-i2c-13-4a"
     label temp1 "board sensor near right PHY"
     set temp1_max 87
     set temp1_max_hyst 77

# U254: tmp75-i2c-13-4c: Board sensor close to left PHY
chip "tmp75-i2c-13-4c"
     label temp1 "board sensor near left PHY"
     set temp1_max 86
     set temp1_max_hyst 76

# U288: tmp75-i2c-13-49: Board sensor betweem Maverick and QSFP
chip "tmp75-i2c-13-49"
     label temp1 "board sensor between switch chip and QSFP"
     set temp1_max 88
     set temp1_max_hyst 78

# U81: tmp75-i2c-13-4f: Board sensor close to fan
chip "tmp75-i2c-13-4f"
     label temp1 "board sensor near fan trays"
     set temp1_max 55
     set temp1_max_hyst 45

# U57: tmp75-i2c-10-4d: Board sensor near CPU
chip "tmp75-i2c-10-4d"
     label temp1 "board sensor near CPU"
     set temp1_max 68
     set temp1_max_hyst 58

# PSU1 and PSU2: 2 temp sensors and a fan sensor
chip "dps460-i2c-14-58"
     label fan1 "psu1 fan"
     label temp1 "psu1 inlet temp"
     label temp2 "psu1 heatsink temp"
     set temp1_max 65
     set temp2_max 65

chip "dps460-i2c-14-59"
     label fan1 "psu1 fan"
     label temp1 "psu1 inlet temp"
     label temp2 "psu1 heatsink temp"
     set temp1_max 65
     set temp2_max 65

# Fan sensors
chip "emc2305-i2c-11-4d"
     ignore fan5

chip "emc2305-i2c-13-4d"
     ignore fan5

# DIMM Temp Sensor
chip "jc42-i2c-0-1a"
     ignore temp1

EOF
    fi
}

# Main program starts here

if [ -r $CACHE_CONF ] ; then
    FAN_CONFIG=$(cat $CACHE_CONF)
    if [ $FAN_CONFIG != "F2B" ] && [ $FAN_CONFIG != "B2F" ] ; then
        log_failure_msg "Unexpected fan config: $FAN_CONFIG"
        exit 1
    fi
else
    detect_fans
    make_sensors_conf $FAN_CONFIG
fi
