#! /usr/bin/python
# Copyright (c) 2017 Cumulus Networks, Inc.  All rights reserved.

#############################################################################
# Platform and model specific eeprom subclass, inherits from the base class,
# and provides the followings:
# - the eeprom format definition
# - specific encoder/decoder if there is special need
#

try:
    import exceptions
    import binascii
    import time
    import optparse
    import warnings
    import os
    import sys
    import subprocess
    import tempfile
    import struct
    import eeprom_ipmi_fru
    import eeprom_tlvinfo
except ImportError, e:
    raise ImportError (str(e) + "- required module not found")

#
# base board
#
class board(eeprom_tlvinfo.TlvInfoDecoder):

    EEPROM_MAX_SIZE = 0x100
    EEPROM_OFFSET = 0x0

    def __init__(self, name, path, cpld_root, ro):
        super(board, self).__init__(path,
                                    self.EEPROM_OFFSET,
                                    "",
                                    ro,
                                    self.EEPROM_MAX_SIZE)
class fan(eeprom_tlvinfo.TlvInfoDecoder):
    EEPROM_MAX_SIZE = 0x100
    EEPROM_OFFSET = 0xa0

    def __init__(self, name, path, cpld_root, ro):
        self.name = name
        super(fan, self).__init__(path,
                                    self.EEPROM_OFFSET,
                                    "",
                                    ro,
                                    self.EEPROM_MAX_SIZE)

    def check_status(self):
        try:
            path = '/sys/class/gpio/fan_tray' + self.name.split('fan')[1] + '_absent/value'
            with open(path, "r") as fp:
                status = fp.readline().strip()
            if status == '0':
                return 'ok'
        except:
            pass
        return 'absent'

class psu(eeprom_ipmi_fru.IpmiFruDecoder):

    def check_status(self):
        path = '/sys/bus/platform/devices/delta_ag9032v1_cpld.0/psu_pwr' + self.name.split('psu')[1]
        try:
            with open(path, "r") as fp:
                status = fp.readline().rstrip()
            if status.find('ok') >= 0:
                return 'ok'
        except:
            pass
        return 'absent'
