#! /usr/bin/python
# Copyright 2014 Cumulus Networks LLC, all rights reserved

#############################################################################
# Platform and model specific eeprom subclass, inherits from the base class,
# and provides the followings:
# - the eeprom format definition
# - specific encoder/decoder if there is special need
#

try:
    import exceptions
    import binascii
    import time
    import optparse
    import warnings
    import os
    import sys
    import eeprom_base
    import eeprom_tlvinfo
except ImportError, e:
    raise ImportError (str(e) + "- required module not found")

# Current TLV based EEPROM format
class board(eeprom_tlvinfo.TlvInfoDecoder):

    EEPROM_OFFSET   = 0x100
    EEPROM_MAX_SIZE = 0x100

    def __init__(self, name, path, cpld_root, ro):
        super(board, self).__init__(path,
                                    self.EEPROM_OFFSET,
                                    "", ro,
                                    self.EEPROM_MAX_SIZE)

    def switchaddrstr(self, e):
        base_mac = super(board, self).switchaddrstr(e)
        return self.increment_mac(base_mac)

#
# power supply unit
#
class psu_dell_format(eeprom_base.eepromDecoder):
    ps_dell_fmt = [ ('burn', 'h', 6),
                    ('vendor_id', 's', 2),
                    ('country_code', 's', 2),
                    ('date', 'd', 8),
                    ('serial_number', 's', 14),
                    ('part_num', 's', 12),
                    ('prod_rev', 's', 2),
                    ('prod_order_num', 's', 25),
                    ('type_id', 'x', 2),
                    ('module_id', 's', 2),
                    ('burn', 's', 19),
                    ('checksum', 'c', 2)
                    ]

    def __init__(self, name, path, cpld_root, ro):
        cpldpath = cpld_root + '/psu_pwr' + name.split('psu')[1]
        super(psu_dell_format, self).__init__(path,
                                  self.ps_dell_fmt,
                                  0,
                                  cpldpath,
                                  ro)
    def is_valid_header(self):
        F = self.open_eeprom()
        F.seek(self.s)
        o = F.read(2)
        i = binascii.b2a_hex(o).upper()
        if i == '3A29':
            return True
        return False

    def decoder(self, s, t):
        if s == 'checksum':
            i = "0x" + binascii.b2a_hex(t).upper()
        elif s == 'header':
            i = "0x" + binascii.b2a_hex(t).upper()
        elif s == 'date':
            i = t[0:2] + '/'+ t[2:4] + '/' + t[4:8]
        elif s == 'type_id':
            x = int(t)
            if x == 1:
                i = 'A/C Normal'
            elif x == 2:
                i = 'A/C Reverse'
            elif x == 3:
                i = 'D/C Normal'
            elif x == 4:
                i = 'D/C Reverse'
            else:
                i = 'Unknown(%d)' %x
        else:
            i = t
        return i

    def check_status(self):
        status = super(psu_dell_format, self).check_status()
        # each device may have a different status string, decide what
        # translates to 'ok' here.
        if status.startswith('installed'):
            return 'ok'
        else:
            return status

    def is_checksum_field(self, I):
        return I[0] == 'checksum'

    def checksum_field_size(self):
        return 2

    def checksum_type(self):
        return 'dell-crc'


def psu(name, path, cpld_root, ro):
    cpld_root = '/sys/devices/ffe05000.localbus/ffdf0000.cpld'
    return psu_dell_format(name, path, cpld_root, ro)
