#! /usr/bin/python

# Copyright (c) 2018 Cumulus Networks, Inc.  All rights reserved

# Platform and model specific eeprom subclass, inherits from the base class,
# and provides the followings:
# - the eeprom format definition
# - specific encoder/decoder if there is special need
#

try:
    import eeprom_tlvinfo
    import eeprom_ipmi_fru
except ImportError, e:
    raise ImportError (str(e) + "- required module not found")

# base board
class board(eeprom_tlvinfo.TlvInfoDecoder):

    EEPROM_MAX_SIZE = 0x100
    EEPROM_OFFSET = 0x0

    def __init__(self, name, path, cpld_root, ro):
        super(board, self).__init__(path,
                                    self.EEPROM_OFFSET,
                                    "",
                                    ro,
                                    self.EEPROM_MAX_SIZE)


# PSUs
class psu(eeprom_ipmi_fru.IpmiFruDecoder):
    EEPROM_MAX_SIZE = 0x100
    EEPROM_OFFSET = 0x0

    def check_status(self):
        path = '/sys/devices/platform/lenovo_ne10032_cpld.0/psu_pwr' + self.name.split('psu')[1] + '_present'
        try:
            with open(path, "r") as fp:
                status = fp.readline().strip()
            if status == '1':
                return 'ok'
        except:
            pass
        return 'absent'


# fans
class fan(eeprom_tlvinfo.TlvInfoDecoder):
    EEPROM_MAX_SIZE = 0x100
    EEPROM_OFFSET = 0x0

    def __init__(self, name, path, cpld_root, ro):
        self.name = name
        super(fan, self).__init__(path,
                                  self.EEPROM_OFFSET,
                                  "",
                                  ro,
                                  self.EEPROM_MAX_SIZE)

    def check_status(self):
        path = '/sys/devices/platform/lenovo_ne10032_cpld.0/fantray' + self.name.split('fan')[1] + '_present'
        try:
            with open(path, "r") as fp:
                status = fp.readline().strip()
                if status == '1':
                    return 'ok'
        except:
            pass
        return 'absent'

