#!/bin/sh

#
# Copyright (c) 2019 Cumulus Networks, Inc.  All rights reserved.
#
# Invoked by /etc/init.d/hw_init
#
# The purpose of this script is to create the sensors config file on the very
# first boot.
#
# First check for the existance of the /etc/sensors.d/lenovo_ne2580.conf
# file.  If the file exists, then exit normally.  If the file doesn't exist,
# determine whether this switch has front-to-back or back-to-front airflow.
# Depending of the result, create the appropriate configuration file.

SENSORS_CONF="/etc/sensors.d/lenovo_ne2580.conf"
CPLD_SYSFS="/sys/bus/i2c/devices/0-0077"
AIRFLOW_DIRECTION="${CPLD_SYSFS}/cpld1_system_airflow"

make_sensors_conf()
{
    airflow_direction=$1

    mkdir -p $(dirname ${SENSORS_CONF})

    cat <<EOF > ${SENSORS_CONF}
# libsensors configuration file for Lenovo NE2580
# -----------------------------------------------
#

# Bus declarations.  These are necessary when using full specified names
# with no wild cards.

#bus "i2c-10" "i2c-0-mux (chan_id 0)"
#bus "i2c-11" "i2c-0-mux (chan_id 1)"


# Intel CPU die temp sensor.  These sensor parameters are read-only.

chip "coretemp-isa-0000"

EOF

    if [ "${airflow_direction}" = "F2B" ] ; then
	cat <<EOF >> ${SENSORS_CONF}

# Front-to-back airflow detected, setting appropriate thresholds.

chip "tmp75-i2c-*-48"
     set temp1_max 62
     set temp1_max_hyst 57

chip "tmp75-i2c-*-4a"
     set temp1_max 60
     set temp1_max_hyst 55

chip "tmp75-i2c-*-4e"
     set temp1_max 60
     set temp1_max_hyst 55

EOF

    else
	cat <<EOF >> ${SENSORS_CONF}

# Back-to-front airflow detected, setting appropriate thresholds.

chip "tmp75-i2c-*-48"
     set temp1_max 60
     set temp1_max_hyst 55

chip "tmp75-i2c-*-4a"
     set temp1_max 67
     set temp1_max_hyst 62

chip "tmp75-i2c-*-4e"
     set temp1_max 64
     set temp1_max_hyst 59

EOF

    fi
}


# Main program starts here

# The configuration file only needs to be created once.  If it already
# exists, don't touch it.

[ -r ${SENSORS_CONF} ] || {

# Sanity check

    [ -d ${CPLD_SYSFS} ] || {
	echo "Unable to find cpld: ${CPLD_SYSFS}"
	exit 1
    }

# Get airflow direction

    [ -r ${AIRFLOW_DIRECTION} ] || {
	echo "Unable to find ${CPLD_SYSFS}: cpld1_system_airflow"
	exit 1
    }
    airflow_direction=$(cat ${AIRFLOW_DIRECTION})

# Create the sensors conf file

    make_sensors_conf ${airflow_direction}

}
