#!/bin/sh

#
# Copyright (c) 2018 Cumulus Networks, Inc.  All rights reserved.
#

# Set the correct modes for all front panel ports

# Load the VERBOSE setting and other rcS variables
. /lib/init/vars.sh

# Define LSB log_* functions.
# Depend on lsb-base (>= 3.2-14) to ensure that this file is present
# and status_of_proc is working.
. /lib/lsb/init-functions

log_action_msg "  Initializing SFP28s/QSFP28s..."

# Turn off tx_disable to all the SFP28 ports
sysfs_base="/sys/devices/pci0000:00/0000:00:1f.3/i2c-0"

[ -w "${sysfs_base}/i2c-14/14-0038/sfp28_1_16_tx_disable" ] || {
    log_failure_msg "Unable for find writeable sysfs file: ${sysfs_base}/i2c-14/14-0038/sfp28_1_16_tx_disable"
    exit 1
}
echo 0x0 > ${sysfs_base}/i2c-14/14-0038/sfp28_1_16_tx_disable

[ -w "${sysfs_base}/i2c-15/15-0038/sfp28_17_32_tx_disable" ] || {
    log_failure_msg "Unable for find writeable sysfs file: ${sysfs_base}/i2c-15/15-0038/sfp28_17_32_tx_disable"
    exit 1
}
echo 0x0 > ${sysfs_base}/i2c-15/15-0038/sfp28_17_32_tx_disable

[ -w "${sysfs_base}/i2c-16/16-0038/sfp28_33_48_tx_disable" ] || {
    log_failure_msg "Unable for find writeable sysfs file: ${sysfs_base}/i2c-16/16-0038/sfp28_33_48_tx_disable"
    exit 1
}
echo 0x0 > ${sysfs_base}/i2c-16/16-0038/sfp28_33_48_tx_disable

# Disable lpmode and reset all the QSFP28 ports
for port in `seq 49 56`; do
    [ -w "/sys/class/gpio/qsfp${port}_lpmode/value" ] || {
	log_failure_msg "Unable for find writeable sysfs file: /sys/class/gpio/qsfp${port}_lpmode/value"
	exit 1
    }

    [ -w "/sys/class/gpio/qsfp${port}_reset/value" ] || {
	log_failure_msg "Unable for find writeable sysfs file: /sys/class/gpio/qsfp${port}_reset/value"
	exit 1
    }

    echo 0 > /sys/class/gpio/qsfp${port}_lpmode/value
    echo 1 > /sys/class/gpio/qsfp${port}_reset/value
done

sleep .1

for port in `seq 49 56`; do
    echo 0 > /sys/class/gpio/qsfp${port}_reset/value
done
