#!/bin/sh

#
# Copyright (c) 2019 Cumulus Networks, Inc.
# All rights reserved.
#

# Program I2C bus monitor and enable automatic BMC recovery.

echo "  Initializing I2C bus monitor..."

ipmitool="/usr/bin/ipmitool"
major=3
minor=6

# First make sure we have the correct version of BMC firmware

if ! [ -x "$(command -v ${ipmitool})" ] ; then
    echo "  Error: ipmitool is not installed." >&2
    exit 1
fi

bmc=`${ipmitool} mc info 2>&1 | awk '/Firmware Revision/{print $NF}'`

bmc_major=`echo $bmc | awk -v FS=. '{print $1}'`
bmc_minor=`echo $bmc | awk -v FS=. '{print $2}'`


[ $bmc_major -gt $major ] || ( [ $bmc_major -eq $major ] && [ $bmc_minor -ge $minor ] ) || {
    echo "  Warning: I2C bus monitor only works with BMC firmware version ${version} or greater"
    exit 1
}

# Program I2C bus monitor reset time of about 5 seconds.
#   Set I2C monitor interval: NetFN=0x36, CMD=0xB3, Para=0x07, Sub-Para={0x14 0x00} (interval)
#   where interval = {0x14, 0x00} in msec = 0x1400 msec = 5.12 sec

${ipmitool} raw 0x36 0xb3 0x4c 0x1c 0x00 0x07 0x14 0x00 > /dev/null 2>&1


# Enable CPLD to monitor the I2C bus
#   Set CPLD I2C watch enable: NetFN=0x36, CMD=0xB3, Para=0x06, Sub-Para=0x01 for Enable or 0x00 for Disable

${ipmitool} raw 0x36 0xb3 0x4c 0x1c 0x00 0x06 0x01 > /dev/null 2>&1


# Set the BMC to auto recover the I2C bus
#   Set BMC auto recovery: NetFN=0x36, CMD=0xB3, Para=0x02, Sub-Para=0x01 for BMC

${ipmitool} raw 0x36 0xb3 0x4c 0x1c 0x00 0x02 0x01 > /dev/null 2>&1

