#!/bin/bash

#
# Copyright 2013 Cumulus Networks, Inc.
# All rights reserved.
#

# Invoked by /etc/init.d/hw_init

# Configure the GPIOs connected to the 4 QFSPs to:
# a) Take the module out of reset
# b) Enable the module

[ "$1" = "start" ] || exit 0

# Load the VERBOSE setting and other rcS variables
. /lib/init/vars.sh

# Define LSB log_* functions.
# Depend on lsb-base (>= 3.2-14) to ensure that this file is present
# and status_of_proc is working.
. /lib/lsb/init-functions

log_action_msg "  Initializing GPIOs.."

# The GPIOs in question are attached to gpiochip240

sysfs_gpio="/sys/class/gpio"
declare -A expected_label=(
["gpiochip96"]="pca9555"
["gpiochip112"]="pca9555"
["gpiochip224"]="/soc8541@e0000000/gpio-controller@90d00"
)
declare -A expected_ngpio=(
["gpiochip96"]="16"
["gpiochip112"]="16"
["gpiochip224"]="32"
)

declare -A gpio_direction=(
["96"]="in"
["97"]="in"
["112"]="in"
["113"]="in"
["246"]="out"
)
# GPIO value will be ignored for "in" direction
declare -A gpio_value=(
["96"]="0"
["97"]="0"
["112"]="0"
["113"]="0"
["246"]="1"
)

# Sanity checking:
for gpiochip in "${!expected_label[@]}"; do
    expected_label=${expected_label["$gpiochip"]}
    expected_ngpio=${expected_ngpio["$gpiochip"]}

    [ -d "$sysfs_gpio/$gpiochip" ] || {
        log_failure_msg "Unable to find GPIO chip: $gpiochip"
        exit 1
    }

    label="$(cat $sysfs_gpio/$gpiochip/label)"
    [ "$label" = "$expected_label" ] || {
        log_failure_msg "Unexpected GPIO chip label: $label"
        exit 1
    }

    ngpio="$(cat $sysfs_gpio/$gpiochip/ngpio)"
    [ "$ngpio" = "$expected_ngpio" ] || {
        log_failure_msg "Unexpected GPIO chip ngpio: $ngpio"
        exit 1
    }
done

for cur_gpio in "${!gpio_direction[@]}"; do
    direction=${gpio_direction["$cur_gpio"]}
    value=${gpio_value["$cur_gpio"]}

    gpio="$sysfs_gpio/gpio${cur_gpio}"
    echo $cur_gpio > "$sysfs_gpio/export"
    [ -d "$gpio" ] || {
        log_failure_msg "Unable to export GPIO: $cur_gpio"
        exit 1
    }
    echo $direction >  "$gpio/direction"
    if [[ $direction == "out" ]]; then
        echo $value >  "$gpio/value"
    fi
done
