#!/bin/bash

#
# Copyright 2014 Cumulus Networks, Inc.
# All rights reserved.
#

# Invoked by /etc/init.d/hw_init

# Configure the GPIOs connected to the 4 QFSPs to:
# a) Take the module out of reset
# b) Enable the module

[ "$1" = "start" ] || exit 0

# Load the VERBOSE setting and other rcS variables
. /lib/init/vars.sh

# Define LSB log_* functions.
# Depend on lsb-base (>= 3.2-14) to ensure that this file is present
# and status_of_proc is working.
. /lib/lsb/init-functions

log_action_msg "  Initializing GPIOs.."

# The GPIOs in question are attached to gpiochip240

sysfs_gpio="/sys/class/gpio"
declare -A expected_label=(
["gpiochip136"]="pca9555"
["gpiochip152"]="pca9555"
["gpiochip168"]="pca9698"
["gpiochip208"]="pca9555"
["gpiochip224"]="/soc@ffe00000/gpio-controller@f000"
)
declare -A expected_ngpio=(
["gpiochip136"]="16"
["gpiochip152"]="16"
["gpiochip168"]="40"
["gpiochip208"]="16"
["gpiochip224"]="32"
)

declare -A gpio_direction=(
#  PSU-2 Present Active:L 
["136"]="in"
# PSU-2 Good Signal Active:H
["137"]="in"
# SFP+ 25-30 Power Enable Active:L
["144"]="out"
# SFP+ 31-36 Power Enable Active:L
["145"]="out"
# SFP+ 37-42 Power Enable Active:L
["146"]="out"
# SFP+ 43-48 Power Enable Active:L
["147"]="out"
# QSFP+ 1-4 Power Enable Active:L
["148"]="out"
# PSU-1 Present Active:L
["152"]="in"
# PSU-1 Good Signal Active:H
["153"]="in"
# SFP+ 1-6 Power Enable Active:L
["160"]="out"
# SFP+ 7-12 Power Enable Active:L
["161"]="out"
# SFP+ 13-18 Power Enable Active:L
["162"]="out"
# SFP+ 19-24 Power Enable Active:L
["163"]="out"
# QSFP+ port1 Module lp mode Active:H
["168"]="out"
# QSFP+ port1 Module present Active:L
["170"]="in"
# QSFP+ port1 Module reset Active:L
["171"]="out"
# QSFP+ port2 Module lp mode Active:H
["176"]="out"
# QSFP+ port2 Module present Active:L
["178"]="in"
# QSFP+ port2 Module reset Active:L
["179"]="out"
# QSFP+ port3 Module lp mode Active:H
["184"]="out"
# QSFP+ port3 Module present Active:L
["186"]="in"
# QSFP+ port3 Module reset Active:L
["187"]="out"
# QSFP+ port4 Module lp mode Active:H
["192"]="out"
# QSFP+ port4 Module present Active:L
["194"]="in"
# QSFP+ port4 Module reset Active:L
["195"]="out"
# Fan-1 Present Active:L
["212"]="in"
# Fan-2 Present Active:L
["213"]="in"
# Fan-3 Present Active:L
["214"]="in"
# System LED status Active:L
["235"]="out"
)
# GPIO value will be ignored for "in" direction
declare -A gpio_value=(
["136"]="0"
["137"]="0"
["144"]="0"
["145"]="0"
["146"]="0"
["147"]="0"
["148"]="0"
["152"]="0"
["153"]="0"
["160"]="0"
["161"]="0"
["162"]="0"
["163"]="0"
["168"]="0"
["171"]="1"
["176"]="0"
["179"]="1"
["184"]="0"
["187"]="1"
["192"]="0"
["195"]="1"
["212"]="0"
["213"]="0"
["214"]="0"
["235"]="1"
)

# Sanity checking:
for gpiochip in "${!expected_label[@]}"; do
    expected_label=${expected_label["$gpiochip"]}
    expected_ngpio=${expected_ngpio["$gpiochip"]}

    [ -d "$sysfs_gpio/$gpiochip" ] || {
        log_failure_msg "Unable to find GPIO chip: $gpiochip"
        exit 1
    }

    label="$(cat $sysfs_gpio/$gpiochip/label)"
    [ "$label" = "$expected_label" ] || {
        log_failure_msg "Unexpected GPIO chip label: $label"
        exit 1
    }

    ngpio="$(cat $sysfs_gpio/$gpiochip/ngpio)"
    [ "$ngpio" = "$expected_ngpio" ] || {
        log_failure_msg "Unexpected GPIO chip ngpio: $ngpio"
        exit 1
    }
done

for cur_gpio in "${!gpio_direction[@]}"; do
    direction=${gpio_direction["$cur_gpio"]}
    value=${gpio_value["$cur_gpio"]}

    gpio="$sysfs_gpio/gpio${cur_gpio}"
    [ -d "$gpio" ] || {
        echo $cur_gpio > "$sysfs_gpio/export"
    }
    [ -d "$gpio" ] || {
        log_failure_msg "Unable to export GPIO: $cur_gpio"
        exit 1
    }
    echo $direction >  "$gpio/direction"
    if [[ $direction == "out" ]]; then
        echo $value >  "$gpio/value"
    fi
done
