#! /usr/bin/python
# Copyright 2012 Cumulus Networks, Inc.
# All rights reserved

#############################################################################
# Platform and model specific eeprom subclass, inherits from the base class,
# and provides the followings:
# - the eeprom format definition
# - specific encoder/decoder if there is special need
#

try:
    import exceptions
    import binascii
    import time
    import optparse
    import warnings
    import os
    import sys
    import subprocess
    import tempfile
    import eeprom_base
    import eeprom_tlvinfo
except ImportError, e:
    raise ImportError (str(e) + "- required module not found")

#
# base board
#
class board(eeprom_tlvinfo.TlvInfoDecoder):

    EEPROM_MAX_SIZE = 0x100

    def __init__(self, name, path, cpld_root, ro):
        super(board, self).__init__(path, 0, "", ro, self.EEPROM_MAX_SIZE)

def bcd_d2b(d):
    '''
    Binary Code Decimal

    Convert decimal number to binary coded decimal

    d - A decimal integer

    Returns an integer
    '''

    # Only expect two digit numbers
    if d > 99:
        raise RuntimeError

    return ((d / 10) * 16) + (d % 10)

#
# power supply unit
#
class psu(eeprom_base.eepromDecoder):
    def __init__(self, name, path, cpld_root, ro):
        raise NotImplementedError

    def decoder(self, s, t):
        pass

    def check_status(self):
        return 'ok'

    def is_checksum_field(self, I):
        return True

    def checksum_field_size(self):
        return 1

    def checksum_type(self):
        return '2s-complement'

