#!/bin/bash

#
# Copyright 2013 Cumulus Networks, Inc.
# All rights reserved.
#

# Invoked by /etc/init.d/hw_init

# Configure the GPIOs connected to the 4 QFSPs to:
# a) Take the module out of reset
# b) Enable the module

[ "$1" = "start" ] || exit 0

# Load the VERBOSE setting and other rcS variables
. /lib/init/vars.sh

# Define LSB log_* functions.
# Depend on lsb-base (>= 3.2-14) to ensure that this file is present
# and status_of_proc is working.
. /lib/lsb/init-functions

log_action_msg "  Initializing GPIOs.."

# The GPIOs in question are attached to gpiochip240

sysfs_gpio="/sys/class/gpio"
declare -A expected_label=(
["gpiochip152"]="pca9555"
["gpiochip168"]="pca9555"
["gpiochip184"]="pca9555"
["gpiochip200"]="pca9554"
["gpiochip208"]="pca9555"
["gpiochip224"]="/soc@ffe00000/gpio-controller@f000"
)
declare -A expected_ngpio=(
["gpiochip152"]="16"
["gpiochip168"]="16"
["gpiochip184"]="16"
["gpiochip200"]="8"
["gpiochip208"]="16"
["gpiochip224"]="32"
)

declare -A gpio_direction=(
["221"]="out"
["152"]="in"
["153"]="in"
["154"]="in"
["155"]="in"
["156"]="in"
["160"]="out"
["172"]="in"
["173"]="in"
["174"]="in"
["176"]="in"
["177"]="in"
["178"]="in"
["180"]="out"
["181"]="out"
["182"]="out"
["184"]="in"
["185"]="in"
["186"]="in"
["187"]="in"
["188"]="in"
["189"]="in"
["190"]="in"
["191"]="in"
["194"]="out"
["195"]="out"
["196"]="out"
["197"]="out"
["198"]="out"
["199"]="out"
["234"]="out"
["235"]="out"
)
# GPIO value will be ignored for "in" direction
declare -A gpio_value=(
["221"]="0"
["160"]="1"
["180"]="0"
["181"]="0"
["182"]="0"
["194"]="0"
["195"]="0"
["196"]="0"
["197"]="0"
["198"]="0"
["199"]="0"
["234"]="0"
["235"]="0"
)

# GPIOs which need to be reset
declare -A gpio_reset=(
["221"]="1"
)

# Sanity checking:
for gpiochip in "${!expected_label[@]}"; do
    expected_label=${expected_label["$gpiochip"]}
    expected_ngpio=${expected_ngpio["$gpiochip"]}

    [ -d "$sysfs_gpio/$gpiochip" ] || {
        log_failure_msg "Unable to find GPIO chip: $gpiochip"
        exit 1
    }

    label="$(cat $sysfs_gpio/$gpiochip/label)"
    [ "$label" = "$expected_label" ] || {
        log_failure_msg "Unexpected GPIO chip label: $label"
        exit 1
    }

    ngpio="$(cat $sysfs_gpio/$gpiochip/ngpio)"
    [ "$ngpio" = "$expected_ngpio" ] || {
        log_failure_msg "Unexpected GPIO chip ngpio: $ngpio"
        exit 1
    }
done

for cur_gpio in "${!gpio_direction[@]}"; do
    direction=${gpio_direction["$cur_gpio"]}

    gpio="$sysfs_gpio/gpio${cur_gpio}"
    echo $cur_gpio > "$sysfs_gpio/export"
    [ -d "$gpio" ] || {
        log_failure_msg "Unable to export GPIO: $cur_gpio"
        exit 1
    }
    echo $direction >  "$gpio/direction"
    if [[ $direction == "out" ]]; then
        value=${gpio_value["$cur_gpio"]}
        echo $value >  "$gpio/value"
    fi
done

for cur_gpio in "${!gpio_reset[@]}"; do

    gpio="$sysfs_gpio/gpio${cur_gpio}"
    value=${gpio_reset["$cur_gpio"]}
    echo $value >  "$gpio/value"

done
