#! /usr/bin/python
# Copyright 2014 Cumulus Networks, Inc.
# All rights reserved

# TODO:  This is just a place holder for the real production code

#############################################################################
# Platform and model specific eeprom subclass, inherits from the base class,
# and provides the followings:
# - the eeprom format definition
# - specific encoder/decoder if there is special need
#

try:
    import exceptions
    import binascii
    import time
    import optparse
    import warnings
    import os
    import sys
    import subprocess
    import tempfile
    import struct
    import eeprom_base
    import eeprom_tlvinfo
    import eeprom_sysfs
except ImportError, e:
    raise ImportError (str(e) + "- required module not found")

#
# base board
#
class board(eeprom_tlvinfo.TlvInfoDecoder):

    EEPROM_MAX_SIZE = 0x100
    EEPROM_OFFSET = 0x0

    def __init__(self, name, path, cpld_root, ro):
        super(board, self).__init__(path,
                                    self.EEPROM_OFFSET,
                                    "",
                                    ro,
                                    self.EEPROM_MAX_SIZE)


#
# CPU board
#
class cpu(eeprom_tlvinfo.TlvInfoDecoder):

    EEPROM_MAX_SIZE = 0x100
    EEPROM_OFFSET = 0x0

    def __init__(self, name, path, cpld_root, ro):
        super(cpu, self).__init__(path,
                                    self.EEPROM_OFFSET,
                                    "",
                                    ro,
                                    self.EEPROM_MAX_SIZE)


#
# power supply unit
#
class psu(eeprom_sysfs.PMBUSDecoder):

    def check_status(self):
        path = '/sys/class/gpio/psu_pwr' + self.name.split('psu')[1] + \
               '_present/value'
        try:
            with open(path, "r") as fp:
                status = fp.readline().rstrip()
            # active low
            if int(status) == 0:
                return 'ok'
            return 'absent'
        except:
            return 'absent'

eeprom_sysfs_map = {
   # name   : [class_name, path] 
    'psu1'  : ['psu', '/sys/bus/i2c/devices/54-0058'],
    'psu2'  : ['psu', '/sys/bus/i2c/devices/55-0059'],
}
