#!/bin/sh

#
# Copyright 2014 Cumulus Networks, Inc.
# All rights reserved.
#

# Configure the MAC address for eth0, using the board EEPROM for the
# MAC address.

# Load the VERBOSE setting and other rcS variables
. /lib/init/vars.sh

# Define LSB log_* functions.
# Depend on lsb-base (>= 3.2-14) to ensure that this file is present
# and status_of_proc is working.
. /lib/lsb/init-functions

config_eth123()
{
    # Make sure eth1, eth2, and eth3 are disabled by default as they
    # are not wired.  Do this before reloading module to cut down on
    # dmesg spam.
    for i in `seq 1 3`
    do
        if [ -f /sys/devices/pci0000:00/0000:00:14.${i}/remove ];
        then
            echo 1 > /sys/devices/pci0000:00/0000:00:14.${i}/remove
        fi
    done
}

drop_82599()
{
    # CL does not ship a driver for the installed 82599 (8086:1557)
    # so we should disable it completely.
    if [ -f /sys/devices/pci0000:00/0000:00:01.0/0000:01:00.0/remove ];
    then
        if [ "$(cat /sys/devices/pci0000:00/0000:00:01.0/0000:01:00.0/device)" = "0x1557" ];
        then
            echo 1 > /sys/devices/pci0000:00/0000:00:01.0/0000:01:00.0/remove
        fi
    fi
}

config_eth0()
{
    mac=$(decode-syseeprom -m) || {
        log_failure_msg "could not find eth0 MAC address in EEPROM"
        return 1
    }
    # Set MAC addr on eth0, but leave the interfaces down.
    ip link set dev eth0 address $mac || {
        log_failure_msg "could not set eth0 MAC address to $mac"
        return 1
    }
}

case "$1" in
  start)
        config_eth123
        config_eth0
        drop_82599
	;;
  *)
	;;
esac
